@@ -2,19 +2,20 @@
 /*  GMime
  *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 2.1
+ *  of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free
+ *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
+ *  02110-1301, USA.
  */
 
 
@@ -644,7 +645,7 @@ parse_broken_date (struct _date_token *tokens, int *tzone)
 					goto next;
 				} else if (!tm.tm_year) {
 					if ((n = get_year (token->start, token->len)) != -1) {
-						printf ("2-digit year; ");
+						d(printf ("2-digit year; "));
 						tm.tm_year = n - 1900;
 					}
 					goto next;
@@ -1056,9 +1057,10 @@ is_rfc2047_token (const char *inptr, size_t len)
 	if (len < 8 || strncmp (inptr, "=?", 2) != 0 || strncmp (inptr + len - 2, "?=", 2) != 0)
 		return FALSE;
 	
-	inptr += 3;
-	len -= 3;
+	inptr += 2;
+	len -= 2;
 	
+	/* skip past the charset */
 	while (*inptr != '?' && len > 0) {
 		inptr++;
 		len--;
@@ -1584,6 +1586,7 @@ rfc2047_decode_word (const char *in, size_t inlen)
 	iconv_t cd;
 	char *buf;
 	
+	/* skip over the charset */
 	if (!(inptr = memchr (inptr, '?', inend - inptr)) || inptr[2] != '?')
 		return NULL;
 	
@@ -1642,9 +1645,10 @@ rfc2047_decode_word (const char *in, size_t inlen)
 		return g_strndup ((char *) decoded, declen);
 	}
 	
-	if ((cd = g_mime_iconv_open ("UTF-8", charset)) == (iconv_t) -1) {
+	if (!charset[0] || (cd = g_mime_iconv_open ("UTF-8", charset)) == (iconv_t) -1) {
 		w(g_warning ("Cannot convert from %s to UTF-8, header display may "
-			     "be corrupt: %s", charset, g_strerror (errno)));
+			     "be corrupt: %s", charset[0] ? charset : "unspecified charset",
+			     g_strerror (errno)));
 		
 		return decode_8bit ((char *) decoded, declen);
 	}
@@ -1703,10 +1707,10 @@ g_mime_utils_header_decode_text (const char *in)
 			ascii = TRUE;
 			
 #ifdef ENABLE_RFC2047_WORKAROUNDS
-			if (!strncmp (inptr, "=?", 2) && inptr[2] != '?') {
+			if (!strncmp (inptr, "=?", 2)) {
 				inptr += 2;
 				
-				/* skip past the charset */
+				/* skip past the charset (if one is even declared, sigh) */
 				while (*inptr && *inptr != '?') {
 					ascii = ascii && is_ascii (*inptr);
 					inptr++;
